# GeyserDockerBuilder

Jenkins pipeline to build a Docker image of Geyser Standalone.

```bash
Dockerfile  # used to build the Docker image
Jenkinsfile # the pipeline file
Readme.md   # you are reading this file
run.sh      # entrypoint of the Docker image
```

## Pipeline process

1. Fetches the information about the latest build of Geyser (version, build number), from the [GeyserMC API](https://download.geysermc.org/v2/projects)
2. Downloads the Geyser Standalone jar file.
3. Builds the docker image with the downloaded jar and the entrypoint script.
4. Pushes the image to the container registry with the tags `latest` and `$geyser_version-$geyser_build` (e.g. `2.2.0-408`)

## Docker Compose Example

```yml
version: "3"
services:
  geyser:
    image: "cr.pandacube.fr/geyser:latest"
    stdin_open: true # docker run -i
    tty: true        # docker run -t
    user: "1000:1000" # uid and gid of owner of working dir 
    environment:
      - MAXMEM=2048M # Java max heap size
    restart: always
    volumes:
      - .:/data/workdir
      - /etc/timezone:/etc/timezone:ro
      - /etc/localtime:/etc/localtime:ro
    ports:
      - "0.0.0.0:(port):19132/udp"
```